@@ -2,10 +2,10 @@ package App::ForkProve;
 
 use strict;
 use 5.008_001;
-use version; our $VERSION = "v0.4.1";
+use version; our $VERSION = "v0.4.2";
 
 use App::Prove;
-use Getopt::Long ':config' => 'pass_through';
+use Getopt::Long ':config' => qw(pass_through no_ignore_case);
 
 use App::ForkProve::SourceHandler;
 
